
Welcome to django-functest's documentation!
===========================================

.. note::

   These docs are for django-functest |release| - please ensure that corresponds
   to the version you are using!

Contents:

.. toctree::
   :maxdepth: 2

   installation
   usage
   common
   selenium
   webtest
   utils
   pytest
   interactive
   contributing
   authors
   history
